@@ -1,7 +1,7 @@
 from nwon_django_toolbox.admin.model_admin_with_json_editor import (
     ModelAdminWithJsonEditor,
     ModelAdminWithJsonEditorReadOnly,
-    PolymorphicChildModelFilterWithJsonEditor,
+    PolymorphicChildModelAdminWithJsonEditor,
     PolymorphicParentModelAdminWithJsonEditor,
 )
 from nwon_django_toolbox.admin.read_only_admin_mixin import (
